@@ -173,7 +173,7 @@ static void irreco_lircdb_dlg_init(IrrecoLircdbDlg *self)
 	/* Create Treeview */
 	self->tree_store = gtk_tree_store_new(
 		N_COLUMNS, G_TYPE_STRING, G_TYPE_INT, G_TYPE_POINTER);
-	self->tree_view = GTK_TREE_VIEW(hildon_gtk_tree_view_new_with_model(1,
+	self->tree_view = GTK_TREE_VIEW(hildon_gtk_tree_view_new_with_model(0,
 		GTK_TREE_MODEL(self->tree_store)));
 
 	renderer = gtk_cell_renderer_text_new();
@@ -220,8 +220,8 @@ static void irreco_lircdb_dlg_init(IrrecoLircdbDlg *self)
 
 	gtk_tree_view_set_enable_tree_lines(self->tree_view, TRUE);
 	g_object_set (G_OBJECT (self->tree_view), "show-expanders", TRUE, NULL);
-	g_object_set (G_OBJECT (self->tree_view), "level-indentation", 0, NULL);
-	gtk_tree_view_set_rubber_banding(self->tree_view, FALSE);
+	/*g_object_set (G_OBJECT (self->tree_view), "level-indentation", 0, NULL);
+	gtk_tree_view_set_rubber_banding(self->tree_view, FALSE);*/
 
 	gtk_widget_set_size_request(GTK_WIDGET(self), -1, 335);
 	gtk_widget_show_all(GTK_WIDGET(self));
@@ -922,9 +922,13 @@ static void irreco_show_lircdb_dlg_row_activated_event(GtkTreeView *tree_view,
 	IRRECO_ENTER
 
 	if (gtk_tree_view_row_expanded(tree_view, path)) {
+		g_print("was expanded\n");
 		gtk_tree_view_expand_row(tree_view, path, FALSE);
+		g_print("tried expand row\n");
 	} else {
+		g_print("was not expanded\n");
 		gtk_tree_view_collapse_row(tree_view, path);
+		g_print("tried collapsing row\n");
 	}
 	IRRECO_RETURN
 }
