@@ -1561,10 +1561,11 @@ gboolean irreco_show_remote_download_dlg(IrrecoData *irreco_data,
 			bg_image = g_string_erase(bg_image, 10, 1);
 			bg_image = g_string_insert_c(bg_image, 10, '1');
 
-			/* Use mmc2 if bg_image does not exists */
+			/* Use /home/user/MyDocs if bg_image does not exists */
 			if (!irreco_file_exists(bg_image->str)) {
-				bg_image = g_string_erase(bg_image, 10, 1);
-				bg_image = g_string_insert_c(bg_image, 10, '2');
+				/*bg_image = g_string_erase(bg_image, 10, 1);
+				bg_image = g_string_insert_c(bg_image, 10, '2');*/
+				bg_image = g_string_assign(bg_image, "/home/user/MyDocs");
 			}
 
 			/* Set bg-image to layout */
